<?php

declare(strict_types=1);

namespace Doctrine\Tests\Models\ValueObjects;

class Name
{
    /** @var string */
    private $firstName;

    /** @var string */
    private $lastName;
}
